@@ -42,7 +42,7 @@ use warnings;
 use UMLS::Similarity;
 
 use vars qw($VERSION);
-$VERSION = '0.01';
+$VERSION = '0.03';
 
 my $debug = 0;
 
@@ -92,11 +92,15 @@ sub getRelatedness
     
     my (@paths) = $interface->findShortestPath($concept1, $concept2);
     
-    my $path = shift @paths;
+    if($#paths < 0) { return; }
+    
+    my $pathstring = shift @paths;
 
-    if($#{$path} < 0 ) { return 0; }
+    my @path = split/\s+/, $pathstring;
 
-    return $#{$path};
+    if($#path < 0 ) { return 0; }
+
+    return $#path;
 }
 
 # Method to return recent error/warning condition
